pyjabber package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pyjabber.db
   pyjabber.features
   pyjabber.network
   pyjabber.plugins
   pyjabber.stanzas
   pyjabber.stream
   pyjabber.utils
   pyjabber.webpage

Submodules
----------

pyjabber.metadata module
------------------------

.. automodule:: pyjabber.metadata
   :members:
   :undoc-members:
   :show-inheritance:

pyjabber.server module
----------------------

.. automodule:: pyjabber.server
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber
   :members:
   :undoc-members:
   :show-inheritance:
